@@ -108,13 +108,20 @@ class DocTree():
 
         return Polygon(points)
 
-    def score(self, a, b):
-        bda = self.create_node(a)
-        bdb = self.create_node(b)
-        
-        score = bda.intersection(bdb).area/bda.area
-    
-        return score
+    def score(self, ra, rb):
+        a = ra['x'], ra['y'], ra['x'] + ra['w'], ra['y'] + ra['h']
+        b = rb['x'], rb['y'], rb['x'] + rb['w'], rb['y'] + rb['h']
+
+        dx = min(a[2], b[2]) - max(a[0], b[0])
+        dy = min(a[3], b[3]) - max(a[1], b[1])
+
+        inter_area = 0.0
+        if (dx>=0) and (dy>=0):
+            inter_area = dx*dy*1.0
+
+        a_area = ra['w']*ra['h']
+
+        return inter_area/a_area
 
     def get_leaves(self, bds):
         bds = [{**bd, 'index':i} for i, bd in enumerate(bds)]
